@@ -23,9 +23,8 @@
 
 #include "../box_db_table.h"
 
-/**
-  *@author Murray Cumming
-  */
+namespace Glom
+{
 
 class Box_DB_Table_Relationships : public Box_DB_Table
 {
@@ -46,12 +45,14 @@ protected:
   virtual void on_adddel_user_changed(const Gtk::TreeModel::iterator& row, guint col);
   virtual void on_adddel_user_requested_delete(const Gtk::TreeModel::iterator& rowStart, const Gtk::TreeModel::iterator& rowEnd);
   virtual void on_adddel_user_added(const Gtk::TreeModel::iterator& row);
-  
+
   guint m_colName, m_colTitle, m_colFromField, m_colToTable, m_colToField, m_colAllowEdit, m_colAutoCreate;
 
   mutable AddDel_WithButtons m_AddDel; //mutable because its get_ methods aren't const.
   Gtk::Button m_Button_Guess;
 };
 
+} //namespace Glom
+
 #endif //BOX_DB_TABLE_RELATIONSHIPS_H
 
